@@ -21,9 +21,15 @@ for cfgfile in access.conf httpd.conf magic mime.types srm.conf ; do
       cp -a etc/apache/${cfgfile}.default etc/apache/${cfgfile}
    fi
 done
+
+# Set the symlink for apachectl only if it doesn't exist.  This allows the mod_ssl
+# package to take over the link easily, and reinstalling apache won't set the link
+# to the wrong version.
+if [ ! -L usr/sbin/apachectl ]; then
+  ( cd usr/sbin ; ln -sf apachectl-standard apachectl )
+fi
+
 ( cd usr/lib ; rm -rf libmm.so )
 ( cd usr/lib ; ln -sf libmm.so.13.0.20 libmm.so )
 ( cd usr/lib ; rm -rf libmm.so.13 )
 ( cd usr/lib ; ln -sf libmm.so.13.0.20 libmm.so.13 )
-( cd usr/sbin ; rm -rf apachectl )
-( cd usr/sbin ; ln -sf apachectl-standard apachectl )
